Module decode

Module decode 

Decoding primitives for MessagePack.

Structs

ArrayDecoder
Decode a MessagePack array of V into Array collecting iterator.
BinDecoder
Decode a MessagePack binary blob and return a borrowed byte slice.
BinOwnedDecoderalloc
Owned Vec<u8> decoder for MessagePack bin8/16/32.
MapDecoder
Decode a MessagePack map of K -> V into Map collecting iterator.
NbyteReader
Helper to read a fixed number of big‑endian bytes and return them as usize.
NilDecoder
Decode the MessagePack nil value.
ReferenceDecoder
Decode a MessagePack binary and return a Reference to its bytes
ReferenceStrBinDecoder
Decode a Messagepack string without utf-8 validation. This is useful for lowering the decoding cost.
ReferenceStrDecoder
Decode a MessagePack string and return a ReferenceStr

Enums

Any
Skip a single MessagePack value from the reader.
Error
MessagePack decode error
ReferenceStr
Borrowed or copied UTF‑8 string reference

Traits

Decode
Decode a value from MessagePack.
DecodeBorrowed
Decode a value whose borrows are bounded by 'de.
DecodeBytes
Trait for decoding MessagePack binary data.
DecodeOwned
Decode a value which owns its data