Module extension

Module extension 

MessagePack extension helpers.

Structs

ExtensionCapacityError
Error indicating that extension payload exceeds the fixed capacity N.
ExtensionOwnedalloc
An owned container for extension payloads.
ExtensionRef
A borrowed view of a MessagePack extension value.
FixedExtension
A fixed-capacity container for extension payloads of up to N bytes.